module.exports = defineTest({
	description: 'does not include unused inner functions and classes'
});
